@@ -2,9 +2,7 @@ package Weed::Component;
 use strict;
 use warnings;
 
-use Weed;
-
-our $DESCRIPTION = '
+use Weed '
 X3DComponent : X3DChildNode {
   SFNode [in,out] metadata NULL [X3DMetadataObject]
 }
