@@ -2,9 +2,9 @@ package Weed::Field::SFComplex;
 use strict;
 use warnings;
 
-our $VERSION = '0.0003';
-
 use Weed 'SFComplex : X3DField { }';
 
+use Math::Complex;
+
 1;
 __END__
